==> react-final-form-fields-2.0.0.tgz: package/src/components/Tiket.stories.js <==
import React from 'react'
import { Form, Field } from 'react-final-form'
import { storiesOf } from '@storybook/react-native'
import styled from 'styled-components/native'
import Input from './TextField'
import Button from './Button'

const tiketContainers = {
  LabelContainer: styled.View`
    position: absolute;
    margin-left: 16;
    max-width: 85;
    bottom: 36;
    z-index: 2;
    background-color: ${props => props.labelBackgroundColor};
    justify-content: center;
    align-items: center;
    padding-horizontal: 5;
  `,
  Label: styled.Text`
    color: ${props => (props.isFocused ? BLUE : props.error ? props.errorTextColor : props.labelTextColor)};
    font-size: 12;
    line-height: 15;
  `,
  FieldContainer: styled.View`
    margin-top: 10;
  `,
}

storiesOf('Custom styles', module)
  //  Primary Button
  .add('Text type', () => (
    <Form onSubmit={console.log} initialValues={{ myInputName: 'Hello' }}>
      {({ handleSubmit }) => <Field type="text" label="Username" name="myInputName" render={Input} />}
    </Form>
  ))
  .add('Phone type', () => (
    <Form onSubmit={console.log} initialValues={{ myInputName: 'Hello' }}>
      {({ handleSubmit }) => (
        <>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            label="Phone number"
            type="phone"
            name="myInputName"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </>
      )}
    </Form>
  ))
  .add('Date type', () => (
    <Form onSubmit={console.log} initialValues={{ myInputName: 'Hello' }}>
      {({ handleSubmit }) => (
        <>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            label="Date"
            type="date"
            name="myInputName"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </>
      )}
    </Form>
  ))
  .add('Password type', () => (
    <Form onSubmit={console.log} initialValues={{ myInputName: 'Hello' }}>
      {({ handleSubmit }) => (
        <>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            label="Password"
            type="password"
            name="myInputName"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </>
      )}
    </Form>
  ))
// .add('Date type', () => (
//   <Form onSubmit={() => {}} initialValues={{ myInputName: 'Hello' }}>
//     {({ handleSubmit }) => (
//       <Field type="date" name="myInputName">
//         {props => (
//           <Container {...props} placeholder="Hello world">
//             {Input}
//           </Container>
//         )}
//       </Field>
//     )}
//   </Form>
// ))
// .add('Password type', () => (
//   <Form onSubmit={() => {}} initialValues={{ myInputName: 'Hello' }}>
//     {({ handleSubmit }) => (
//       <Field type="password" name="myInputName">
//         {props => (
//           <Container {...props} placeholder="Hello world">
//             {Input}
//           </Container>
//         )}
//       </Field>
//     )}
//   </Form>
// ))

==> react-final-form-fields-2.0.5.tgz: package/src/components/Tiket.stories.js <==
import React from 'react'
import { View } from 'react-native'
import { Form, Field } from 'react-final-form'
import { storiesOf } from '@storybook/react-native'
import styled from 'styled-components/native'
// import { isPhone } from 'react-final-form-fields-validate'

import Input from './TextField'
import Button from './Button'

// color: ${({ meta }) => (meta && meta.active !== undefined ? 'blue' : meta.error ? 'pink' : 'gray')};

const tiketContainers = {
  OuterContainer: styled.View`
    border-style: dotted;
    border-color: green;
    border-width: 3;
    width: 100%;
    padding-vertical: 15;
    padding-horizontal: 15;
  `,
  LabelContainer: styled.View`
    position: absolute;
    margin-left: 16;
    max-width: 85;
    top: 10;
    z-index: 2;
    background-color: ${({ meta: { error } }) => (error ? 'white' : 'white')};
    justify-content: center;
    align-items: center;
    padding-horizontal: 5;
  `,
  Label: styled.Text`
    color: red;
    font-size: 12;
    line-height: 15;
  `,
  FieldContainer: styled.View`
    margin-top: 10;
    width: 100%;
    flex-grow: 1;
    flex-direction: row;
  `,
  ErrorContainer: styled.View``,
  ErrorText: styled.Text`
    color: pink;
  `,
}

storiesOf('Custom styles', module)
  //  Primary Button
  .add('Text type', () => (
    <Form onSubmit={console.log}>
      {({ handleSubmit }) => (
        <Field
          containers={tiketContainers}
          type="text"
          label="Username"
          name="Username"
          placeholder="Username"
          render={Input}
        />
      )}
    </Form>
  ))
  .add('Phone type', () => (
    <Form onSubmit={console.log}>
      {({ handleSubmit }) => (
        <View>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            label="Phone number"
            type="phone"
            name="phone"
            placeholder="Phone"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </View>
      )}
    </Form>
  ))
  .add('Date type', () => (
    <Form onSubmit={console.log}>
      {({ handleSubmit }) => (
        <>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            label="Date"
            placeholder="Date"
            type="date"
            name="date"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </>
      )}
    </Form>
  ))
  .add('Password type', () => (
    <Form onSubmit={console.log}>
      {({ handleSubmit }) => (
        <>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            placeholder="Password"
            label="Password"
            type="password"
            name="password"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </>
      )}
    </Form>
  ))
// .add('Date type', () => (
//   <Form onSubmit={() => {}}>
//     {({ handleSubmit }) => (
//       <Field type="date" name="myInputName">
//         {props => (
//           <Container {...props} placeholder="Hello world">
//             {Input}
//           </Container>
//         )}
//       </Field>
//     )}
//   </Form>
// ))
// .add('Password type', () => (
//   <Form onSubmit={() => {}}>
//     {({ handleSubmit }) => (
//       <Field type="password" name="myInputName">
//         {props => (
//           <Container {...props} placeholder="Hello world">
//             {Input}
//           </Container>
//         )}
//       </Field>
//     )}
//   </Form>
// ))
